# `testmswist`

* op1
* op2
* op3


# Install

```python
pip install testmswist
```

# Usage

```python
from testmswist.m_mod_mswist import name as n

>> > n("Name", "Surname")
Witaj: Name
Surname
```